@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ARTICLEGRANTLEEOBJECT_H
@@ -61,20 +48,12 @@ public:
     Q_REQUIRED_RESULT QString articleCompleteStoryLink() const;
     Q_REQUIRED_RESULT QString imageFeed() const;
 
-    //Action
-    Q_REQUIRED_RESULT QString deleteAction() const;
-    Q_REQUIRED_RESULT QString markAsReadAction() const;
-    Q_REQUIRED_RESULT QString markAsUnreadAction() const;
-    Q_REQUIRED_RESULT QString markAsImportantAction() const;
-    Q_REQUIRED_RESULT QString sendUrlAction() const;
-    Q_REQUIRED_RESULT QString sendFileAction() const;
-
     Q_REQUIRED_RESULT bool important() const;
     Q_REQUIRED_RESULT QString actionToken() const;
 
 private:
-    Article mArticle;
-    ArticleFormatter::IconOption mArticleFormatOption;
+    const Article mArticle;
+    const ArticleFormatter::IconOption mArticleFormatOption;
 };
 }
 #endif // ARTICLEGRANTLEEOBJECT_H
