@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2007 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2007 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "selectioncontroller.h"
@@ -181,7 +165,7 @@ void SelectionController::setFeedList(const QSharedPointer<FeedList> &list)
     }
 
     m_feedList = list;
-    SubscriptionListModel *m = qobject_cast<SubscriptionListModel *>(m_subscriptionModel->sourceModel());
+    auto *m = qobject_cast<SubscriptionListModel *>(m_subscriptionModel->sourceModel());
     std::unique_ptr<SubscriptionListModel> oldModel(m);
     m_subscriptionModel->setSourceModel(new SubscriptionListModel(m_feedList, this));
 
@@ -243,9 +227,7 @@ void SelectionController::articleHeadersAvailable(KJob *job)
     disconnect(m_articleLister->articleSelectionModel(), &QItemSelectionModel::selectionChanged, this, &SelectionController::articleSelectionChanged);
     connect(m_articleLister->articleSelectionModel(), &QItemSelectionModel::selectionChanged, this, &SelectionController::articleSelectionChanged);
 
-    if (node) {
-        m_articleLister->setScrollBarPositions(node->listViewScrollBarPositions());
-    }
+    m_articleLister->setScrollBarPositions(node->listViewScrollBarPositions());
 }
 
 void SelectionController::subscriptionDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
@@ -260,7 +242,7 @@ void SelectionController::subscriptionDataChanged(const QModelIndex &topLeft, co
     }
 
     //need access to setExpanded
-    QTreeView *tv = qobject_cast<QTreeView *>(m_feedSelector);
+    auto *tv = qobject_cast<QTreeView *>(m_feedSelector);
     if (!tv) {
         qCCritical(AKREGATOR_LOG) << "Unable to cast m_feedSelector to QTreeView";
         return;
@@ -305,7 +287,7 @@ void SelectionController::selectedSubscriptionChanged(const QModelIndex &index)
         return;
     }
 
-    ArticleListJob *const job(new ArticleListJob(m_selectedSubscription));
+    auto *const job(new ArticleListJob(m_selectedSubscription));
     connect(job, &KJob::finished,
             this, &SelectionController::articleHeadersAvailable);
     m_listJob = job;
@@ -321,7 +303,7 @@ void SelectionController::subscriptionContextMenuRequested(const QPoint &point)
     }
 
     QWidget *w = ActionManager::getInstance()->container(node->isGroup() ? QStringLiteral("feedgroup_popup") : QStringLiteral("feeds_popup"));
-    QMenu *popup = qobject_cast<QMenu *>(w);
+    auto *popup = qobject_cast<QMenu *>(w);
     if (popup) {
         const QPoint globalPos = m_feedSelector->viewport()->mapToGlobal(point);
         popup->exec(globalPos);
